==> ideaIC-182.3208.16-sources.jar: com/android/tools/idea/naveditor/property/NavPropertiesPanel.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.naveditor.property;

import com.android.tools.idea.common.model.NlComponent;
import com.android.tools.idea.common.property.PropertiesPanel;
import com.android.tools.idea.common.property.inspector.InspectorPanel;
import com.android.tools.idea.naveditor.property.inspector.NavInspectorPanel;
import com.android.tools.idea.uibuilder.property.NlPropertyItem;
import com.google.common.collect.Table;
import com.intellij.openapi.actionSystem.DataContext;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.awt.*;
import java.util.List;

/**
 * TODO
 */
public class NavPropertiesPanel extends PropertiesPanel<NavPropertiesManager> {

  private final NavPropertiesManager myPropertiesManager;
  private final InspectorPanel<NavPropertiesManager> myInspectorPanel;

  public NavPropertiesPanel(@NotNull NavPropertiesManager propertiesManager) {
    super(new BorderLayout());
    myPropertiesManager = propertiesManager;
    myInspectorPanel = new NavInspectorPanel(this);
    add(myInspectorPanel, BorderLayout.CENTER);
  }

  @Override
  public void activatePreferredEditor(@NotNull String propertyName, boolean afterLoad) {

  }

  @Override
  public void setItems(@NotNull List<NlComponent> components,
                       @NotNull Table<String, String, NlPropertyItem> properties) {
    myInspectorPanel.setComponent(components, properties, myPropertiesManager);
  }

  @Override
  public void performCopy(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean isCopyEnabled(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public boolean isCopyVisible(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void performCut(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean isCutEnabled(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public boolean isCutVisible(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void deleteElement(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean canDeleteElement(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void performPaste(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean isPastePossible(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public boolean isPasteEnabled(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void dispose() {

  }

  @Nullable
  @Override
  public Object getData(String dataId) {
    return null;
  }
}

==> ideaIC-201.6668.113-sources.jar: com/android/tools/idea/naveditor/property/NavPropertiesPanel.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.naveditor.property;

import com.android.tools.idea.common.model.NlComponent;
import com.android.tools.idea.common.property.NlProperty;
import com.android.tools.idea.common.property.PropertiesPanel;
import com.android.tools.idea.common.property.inspector.InspectorPanel;
import com.android.tools.idea.naveditor.property.inspector.NavInspectorPanel;
import com.android.tools.idea.uibuilder.property.NlPropertyItem;
import com.google.common.collect.HashBasedTable;
import com.google.common.collect.Table;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.util.Disposer;
import com.intellij.ui.ScrollPaneFactory;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.awt.*;
import java.util.List;

/**
 * TODO
 */
public class NavPropertiesPanel extends PropertiesPanel {
  private final NavPropertiesManager myPropertiesManager;
  private final InspectorPanel<NavPropertiesManager> myInspectorPanel;

  public NavPropertiesPanel(@NotNull NavPropertiesManager propertiesManager) {
    super(new BorderLayout());
    myPropertiesManager = propertiesManager;
    myInspectorPanel = new NavInspectorPanel(this);
    JScrollPane scrollPane = ScrollPaneFactory.createScrollPane(myInspectorPanel,
                                                                ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED,
                                                                ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
    scrollPane.setBorder(null);
    add(scrollPane, BorderLayout.CENTER);
    Disposer.register(myPropertiesManager, this);
  }

  @Override
  public void activatePreferredEditor(@NotNull String propertyName, boolean afterLoad) {

  }

  @Override
  public void modelRendered() {
    myInspectorPanel.refresh();
  }

  @Override
  public void setItems(@NotNull List<NlComponent> components,
                       @NotNull Table<String, String, NlPropertyItem> properties) {
    Table<String, String, NlProperty> wrappedProperties = HashBasedTable.create();
    for (String rowKey : properties.rowKeySet()) {
      for (String columnKey : properties.row(rowKey).keySet()) {
        NlProperty wrapped = new NavPropertyWrapper(properties.get(rowKey, columnKey));
        wrappedProperties.put(rowKey, columnKey, wrapped);
      }
    }
    myInspectorPanel.setComponent(components, wrappedProperties, myPropertiesManager);
  }

  @Override
  public void performCopy(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean isCopyEnabled(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public boolean isCopyVisible(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void performCut(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean isCutEnabled(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public boolean isCutVisible(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void deleteElement(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean canDeleteElement(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void performPaste(@NotNull DataContext dataContext) {

  }

  @Override
  public boolean isPastePossible(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public boolean isPasteEnabled(@NotNull DataContext dataContext) {
    return false;
  }

  @Override
  public void dispose() {

  }

  @Nullable
  @Override
  public Object getData(@NotNull String dataId) {
    return null;
  }
}
